Struct rtest_util::TestArguments
source · pub struct TestArguments {
pub module: Option<String>,
pub group: Option<String>,
pub cost: Option<u32>,
pub responsible: Option<String>,
}Expand description
TestArguments specifies every possible setting a test can have. This can be used to specify a responsible, set groups, or similar for a test
Fields
module: Option<String>specifies the module your test lives in
group: Option<String>only relevant for displaying, tests in one group will be displayed together
cost: Option<u32>responsible: Option<String>Trait Implementations
sourceimpl Debug for TestArguments
impl Debug for TestArguments
sourceimpl Default for TestArguments
impl Default for TestArguments
sourcefn default() -> TestArguments
fn default() -> TestArguments
Returns the “default value” for a type. Read more